@@ -15,16 +15,21 @@
  */
 
 use crate::errors::*;
+use crate::model_evaluator::ModelEvaluator;
 use dmntk_common::Result;
 use dmntk_feel::context::FeelContext;
-use dmntk_feel::value_null;
 use dmntk_feel::values::Value;
-use dmntk_model::model::Definitions;
+use dmntk_model::model::{Definitions, DmnElement, NamedElement};
 
 /// Evaluates a decision service specified by name.
-pub fn eval_decision_service_by_name(definitions: &Definitions, name: &str, _ctx: &FeelContext) -> Result<Value> {
-  if let Some(_decision) = definitions.decision_service_by_name(name) {
-    Ok(value_null!())
+pub fn eval_decision_service_by_name(definitions: &Definitions, name: &str, input_data: &FeelContext) -> Result<Value> {
+  if let Some(decision_service) = definitions.decision_service_by_name(name) {
+    println!("AAA: <DECISION_SERVICE_NAME> = {}", decision_service.name());
+    println!("AAA: <INPUT_DATA>    = {}", input_data);
+    let id = decision_service.id().as_ref().ok_or_else(err_empty_identifier)?;
+    let model_evaluator = ModelEvaluator::new(definitions)?;
+    let result = model_evaluator.evaluate_decision_service(id, input_data);
+    Ok(result)
   } else {
     Err(err_decision_service_with_name_not_found(name))
   }
